<?php
/*
 /////////////////// DISCLAIMER ///////////////////////////
 THIS EXAMPLE CODE IS PROVIDED TO YOU ONLY ON AN "AS IS"
 BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
 ANY WARRANTIES OR CONDITIONS OF TITLE, NON-INFRINGEMENT,
 MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 PAYPAL MAKES NO WARRANTY THAT THE SOFTWARE OR
 DOCUMENTATION WILL BE ERROR-FREE. IN NO EVENT SHALL THE
 COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ////////////////////////////////////////////////////////////
 */

//Get access token from PayPal
include 'create-token.php';

//Print all errors
error_reporting(E_ALL);
ini_set("display_errors", 1);


//Initiate CURL and set the url endpoint
$ch = curl_init();
$url = 'https://api.sandbox.paypal.com/v2/checkout/orders';
curl_setopt($ch, CURLOPT_URL, $url);

curl_setopt($ch, CURLOPT_SSLVERSION, CURL_SSLVERSION_TLSv1_2);

//Should to be set to true for security
curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
//Should be set to 2 for security
curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);

//Cert can be generated through mozilla firefox and is used when implementing security for VERIFYPEER and VERIFYHOST in the above
//curl_setopt($ch, CURLOPT_CAINFO, '/var/www/html/Example_REST_ECS/cert/cacert.pem');

//Set the required headers
$headers = array(
    'Accept: application/json',
    'Content-Type: application/json',
    "Authorization: Bearer $accessToken"
);
curl_setopt($ch,CURLOPT_HTTPHEADER,$headers);

//Lets curl know we are using 'post' and not 'get' (false = 'get')
curl_setopt($ch, CURLOPT_POST, TRUE);

//Keep connection open until we get data back
curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);

//Specify we want to capture the payment, change this to 'AUTHORIZE' if you only want authorize the payment 
$vars['intent'] = 'CAPTURE';

//--------------------------------------------------------------------
//Specify shipping name
$name['full_name'] = "Fake Buyer";
$shipping['name'] = $name;
$shipping['type'] = "SHIPPING";

//Specify shipping address for transaction
$address['address_line_1'] = '10 Downing Street';
$address['address_line_2'] = "WestMinster";
//City
$address['admin_area_2'] = "London";
//County
$address['admin_area_1'] = "London";
$address['postal_code'] = "SW1A 2AA";
$address['country_code'] = "GB";

$shipping['address'] = $address;
$purchase_units['shipping'] = $shipping;

//------------------------------------------------------------------

//Define unit and tax amounts for first item
$unitAmount1['currency_code'] = "GBP";
$unitAmount1['value'] = "10";
$taxAmount1['currency_code'] = "GBP";
$taxAmount1['value'] = "1";

//Define first item
$item1['name'] = 'Item 1';
$item1['unit_amount'] = $unitAmount1;
$item1['tax'] = $taxAmount1;
$item1['quantity'] = '1';
$item1['description'] = 'Description for Item 1';
$item1['sku'] = 'ABC123';
//Can also be DIGITAL_GOODS
$item1['category'] = "PHYSICAL_GOODS";

//------------------------------------------------------------------

//Define unit and tax amounts for second item
$unitAmount2['currency_code'] = "GBP";
$unitAmount2['value'] = "20";
$taxAmount2['currency_code'] = "GBP";
$taxAmount2['value'] = "2";

//Define second item
$item2['name'] = 'Item 2';
$item2['unit_amount'] = $unitAmount2;
$item2['tax'] = $taxAmount2;
$item2['quantity'] = '1';
$item2['description'] = 'Description for Item 2';
$item2['sku'] = 'ABC123';
//Can also be DIGITAL_GOODS
$item2['category'] = "PHYSICAL_GOODS";

//Add items to array and request
$items = array($item1, $item2);
$purchase_units['items'] = $items;

//------------------------------------------------------------------

//Add invoce to request
//$purchase_units['invoice_id'] = "001";

//Define Payee Information
$payee['email_address'] = 'brian_uk_seller@fake.com';
$payee['merchant_id'] = 'LKMBPUFVYHVYL';
$purchase_units['payee'] = $payee;

//------------------------------------------------------------------

//Specify currency and amount for transaction
$amount['currency_code'] = 'GBP';
$amount['value'] = '34.50';

//Specify the item total for the transction
$itemTotal['currency_code'] = 'GBP';
$itemTotal['value'] = '30';

//Specify the shipping total for the transction
$shippingTotal['currency_code'] = 'GBP';
$shippingTotal['value'] = '1.50';

//Specify the handling total for the transction
$handlingTotal['currency_code'] = 'GBP';
$handlingTotal['value'] = '0';

//Specify the tax total for the transction
$taxTotal['currency_code'] = 'GBP';
$taxTotal['value'] = '3';

//Specify the insurance total for the transction
$insuranceTotal['currency_code'] = 'GBP';
$insuranceTotal['value'] = '0';

//Specify the total shipping discount for the transction
$shippingDiscount['currency_code'] = 'GBP';
$shippingDiscount['value'] = '0';

//Specify the total discount for the transction
$discount['currency_code'] = 'GBP';
$discount['value'] = '0';

$breakdown['item_total'] = $itemTotal;
$breakdown['shipping'] = $shippingTotal;
$breakdown['handling'] = $handlingTotal;
$breakdown['tax_total'] = $taxTotal;
$breakdown['insurance'] = $insuranceTotal;
$breakdown['shipping_discount'] = $shippingDiscount;
$breakdown['discount'] = $discount;

$amount['breakdown'] = $breakdown;

//Add the transaction values to the amount array
$purchase_units['amount'] = $amount;

//------------------------------------------------------------------


//Add the purchase_units array to the main array
$vars['purchase_units'] = Array($purchase_units);

//------------------------------------------------------------------


//Build and set the request
$json = json_encode($vars);

//echo $json;

curl_setopt($ch, CURLOPT_POSTFIELDS, $json);

//Get the response back
$response = curl_exec($ch);

//parse json into object
$outArray = json_decode($response, true);

//Set the order id in the session for later use
$_SESSION['orderId'] = $outArray['id'];

//print the response to be returned to the javascript the initially called it
echo $response;


//Close the connection
curl_close($ch);

